@@ -40,21 +40,31 @@ logger = get_logger(__name__, formatter_template=5)
 
 # 配置连接信息
 try:
-    import redis_queue_tool_config
+    import redis_queue_tool_config as leek_config
 
-    default_config.redis_host = redis_queue_tool_config.redis_host
-    default_config.redis_password = redis_queue_tool_config.redis_password
-    default_config.redis_port = redis_queue_tool_config.redis_port
-    default_config.redis_db = redis_queue_tool_config.redis_db
-    default_config.kafka_host = redis_queue_tool_config.kafka_host
-    default_config.kafka_port = redis_queue_tool_config.kafka_port
-    default_config.kafka_username = redis_queue_tool_config.kafka_port
-    default_config.kafka_password = redis_queue_tool_config.kafka_password
-    logger.info('读取到redis_queue_tool_config.py配置,使用自定义配置')
+    default_config.redis_host = leek_config.redis_host
+    default_config.redis_password = leek_config.redis_password
+    default_config.redis_port = leek_config.redis_port
+    default_config.redis_db = leek_config.redis_db
+    default_config.redis_ssl = leek_config.redis_ssl
+    logger.info('读取到redis_queue_tool.py redis配置')
 except ModuleNotFoundError:
-    logger.warning('未读取redis_queue_tool_config.py自定义配置文件,使用默认配置文件')
+    logger.warning('未读取到redis_queue_tool.py redis配置.')
 except AttributeError:
-    logger.warning('未读取redis_queue_tool_config.py自定义连接属性,使用默认属性')
+    logger.warning('未读取到redis_queue_tool.py redis配置。')
+
+try:
+    import redis_queue_tool_config as leek_config
+
+    default_config.kafka_host = leek_config.kafka_host
+    default_config.kafka_port = leek_config.kafka_port
+    default_config.kafka_username = leek_config.kafka_username
+    default_config.kafka_password = leek_config.kafka_password
+    logger.info('读取到redis_queue_tool.py kafka配置,使用自定义配置')
+except ModuleNotFoundError:
+    logger.warning('未读取到redis_queue_tool.py kafka配置.')
+except AttributeError:
+    logger.warning('未读取到redis_queue_tool.py kafka配置。')
 
 
 def init_redis_config(host, password, port, db):
@@ -99,7 +109,9 @@ class RedisCustomer(object):
         elif middleware == MiddlewareEum.MEMORY:
             self._redis_quenen = MemoryQueue(queue_name=queue_name)
         else:
-            self._redis_quenen = RedisQueue(queue_name, priority=priority, host=default_config.redis_host,
+            self._redis_quenen = RedisQueue(queue_name, priority=priority,
+                                            ssl=default_config.redis_ssl,
+                                            host=default_config.redis_host,
                                             port=default_config.redis_port,
                                             db=default_config.redis_db,
                                             password=default_config.redis_password)
@@ -121,8 +133,8 @@ class RedisCustomer(object):
         self.ack = ack
         self.middleware = middleware
         self.publisher_queue = RedisPublish(queue_name, fliter_rep=fliter_rep, priority=priority,
-                                               middleware=MiddlewareEum.REDIS,
-                                               consuming_function=consuming_function)
+                                            middleware=MiddlewareEum.REDIS,
+                                            consuming_function=consuming_function)
 
     # noinspection PyBroadException
     def _start_consuming_message_thread(self):
